#!/bin/sh

RRDPATH=/root
PNGPATH=/var/www

# $1 - id
create()
{
  rrdtool create $RRDPATH/apc-$1.rrd \
  DS:BatteryCapacity:GAUGE:600:0:100 \
  DS:BatteryTemperature:GAUGE:600:U:U \
  DS:InputLineVoltage:GAUGE:600:0:U \
  DS:InputMinLineVoltage:GAUGE:600:0:U \
  DS:InputMaxLineVoltage:GAUGE:600:0:U \
  DS:InputFrequency:GAUGE:600:0:U \
  DS:OutputVoltage:GAUGE:600:0:U \
  DS:OutputFrequency:GAUGE:600:0:U \
  DS:OutputLoad:GAUGE:600:0:100 \
  DS:OutputCurrent:GAUGE:600:0:U \
  DS:NumDevices:GAUGE:600:0:U \
  RRA:AVERAGE:0.5:1:288 \
  RRA:AVERAGE:0.5:12:336 \
  RRA:AVERAGE:0.5:228:366 \
  RRA:AVERAGE:0.5:2016:261
}

# $1 - id
# $2 - host ip
# $3 - community
update()
{
  a=`snmpget -v1 -c $3 -m +/root/mibs/POWERNET-MIB -Ov $2 \
  upsAdvBatteryCapacity.0 \
  upsAdvBatteryTemperature.0 \
  upsAdvInputLineVoltage.0 \
  upsAdvInputMinLineVoltage.0 \
  upsAdvInputMaxLineVoltage.0 \
  upsAdvInputFrequency.0 \
  upsAdvOutputVoltage.0 \
  upsAdvOutputFrequency.0 \
  upsAdvOutputLoad.0 \
  upsAdvOutputCurrent.0 \
  upsBasicConfigNumDevices.0 \
  | awk '{printf ":"$2;}'`

  rrdtool update $RRDPATH/apc-$1.rrd N$a
}

# $1 - id
# $2 - period
build()
{
  # Battery capacity and output loading
  rrdtool graph $PNGPATH/apc-$1-battery-loading-$2.png --start=now-$2 --end=now \
  --width 480 --height 240 \
  --slope-mode --vertical-label 'Емкость батареи и нагрузка в процентах' \
  --title "APC $1 ёмкость батареи и нагрузка, $2" \
  DEF:capacity=$RRDPATH/apc-$1.rrd:BatteryCapacity:AVERAGE \
  'LINE2:capacity#0000FFFF:Ёмкость батареи' \
  DEF:loading=$RRDPATH/apc-$1.rrd:OutputLoad:AVERAGE \
  'LINE2:loading#FF0000FF:Нагрузка' > /dev/null 2>&1

  # Battery temperature, output amperage, number of devices
  rrdtool graph $PNGPATH/apc-$1-temp-amper-numdevs-$2.png --start=now-$2 --end=now \
  --width 480 --height 240 \
  --slope-mode --vertical-label 'Температура, сила тока, количество устройств' \
  --title "APC $1 температура, сила тока, количество устройств, $2" \
  DEF:temperature=$RRDPATH/apc-$1.rrd:BatteryTemperature:AVERAGE \
  'LINE2:temperature#0000FFFF:Температура батареи, градусы Цельсия' \
  DEF:amperage=$RRDPATH/apc-$1.rrd:OutputCurrent:AVERAGE \
  'LINE2:amperage#FF0000FF:Выходной ток, Амперы' \
  DEF:numdevs=$RRDPATH/apc-$1.rrd:NumDevices:AVERAGE \
  'LINE2:numdevs#00FF00FF:Количество устройств' > /dev/null 2>&1

  # Voltage and frequencies
  rrdtool graph $PNGPATH/apc-$1-voltage-freq-$2.png --start=now-$2 --end=now \
  --width 480 --height 240 \
  --slope-mode --vertical-label 'Напряжение и частота на входе и выходе' \
  --title "APC $1 напряжение и частота на входе и выходе, $2" \
  DEF:in=$RRDPATH/apc-$1.rrd:InputLineVoltage:AVERAGE \
  CDEF:in2=0,in,- \
  'LINE2:in2#0000FFFF:Входное напряжение, Вольт' \
  DEF:inmax=$RRDPATH/apc-$1.rrd:InputMaxLineVoltage:AVERAGE \
  CDEF:inmax2=0,inmax,- \
  'LINE1:inmax2#FF00FFFF:Максимальное входное напряжение, Вольт' \
  DEF:inmin=$RRDPATH/apc-$1.rrd:InputMinLineVoltage:AVERAGE \
  CDEF:inmin2=0,inmin,- \
  'LINE1:inmin2#00FFFFFF:Минимальное входное напряжение, Вольт' \
  DEF:infreq=$RRDPATH/apc-$1.rrd:InputFrequency:AVERAGE \
  CDEF:infreq2=0,infreq,- \
  'LINE1:infreq2#0000FFFF:Входная частота, Герц' \
  DEF:out=$RRDPATH/apc-$1.rrd:OutputVoltage:AVERAGE \
  'LINE2:out#FF0000FF:Выходное напряжение, Вольт' \
  DEF:outfreq=$RRDPATH/apc-$1.rrd:OutputFrequency:AVERAGE \
  'LINE1:outfreq#FF0000FF:Выходная частота, Герц' \
  LINE1:0#000000FF > /dev/null 2>&1
}

# $1 - id
html()
{

cat - > $PNGPATH/apc-$1.html <<END
<html>
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <title>Графики параметров APC #$1</title>
  </head>
  <body>
    <div align="center">
    <h3>Графики параметров APC #$1</h3>
      <table>
        <tr>
          <td id="battery-loading"><img src="apc-$1-battery-loading-1day.png"></td>
          <td><img src="apc-$1-battery-loading-2weeks.png"></td>
          <td><a href="apc-$1-arc.html#battery-loading">&gt;&gt;</a></td>
        </tr>
        <tr>
          <td id="temp-amper-numdevs"><img src="apc-$1-temp-amper-numdevs-1day.png"></td>
          <td><img src="apc-$1-temp-amper-numdevs-2weeks.png"></td>
          <td><a href="apc-$1-arc.html#temp-amper-numdevs">&gt;&gt;</a></td>
        </tr>
        <tr>
          <td id="voltage-freq"><img src="apc-$1-voltage-freq-1day.png"></td>
          <td><img src="apc-$1-voltage-freq-2weeks.png"></td>
          <td><a href="apc-$1-arc.html#voltage-freq">&gt;&gt;</a></td>
        </tr>
      </table>
    </div>
  </body>
</html>
END

cat - > $PNGPATH/apc-$1-arc.html <<END
<html>
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <title>Графики параметров APC #$1</title>
  </head>
  <body>
    <div align="center">
    <h3>Графики параметров APC #$1</h3>
      <table>
        <tr>
          <td><a href="apc-$1.html#battery-loading">&lt;&lt;</a></td>
          <td id="battery-loading"><img src="apc-$1-battery-loading-1year.png"></td>
          <td><img src="apc-$1-battery-loading-5years.png"></td>
        </tr>
        <tr>
          <td><a href="apc-$1.html#temp-amper-numdevs">&lt;&lt;</a></td>
          <td id="temp-amper-numdevs"><img src="apc-$1-temp-amper-numdevs-1year.png"></td>
          <td><img src="apc-$1-temp-amper-numdevs-5years.png"></td>
        </tr>
        <tr>
          <td><a href="apc-$1.html#voltage-freq">&lt;&lt;</a></td>
          <td id="voltage-freq"><img src="apc-$1-voltage-freq-1year.png"></td>
          <td><img src="apc-$1-voltage-freq-5years.png"></td>
        </tr>
      </table>
    </div>
  </body>
</html>
END

}

case "$1" in
  create)
    create $2
  ;;
  update)
    update $2 $3 $4
  ;;
  build)
    build $2 $3
  ;;
  html)
    html $2
  ;;
  *)
    NAME=`basename $0`
    echo "$NAME - Tracking parameters from APC"
    echo "Usage: $NAME create <id> - create database with <id>"
    echo "       $NAME update <id> <ip> <community> - fetch counters from router to database"
    echo "       $NAME build <id> <period> - build graph for <period>"
    echo "       $NAME html <id> - build html's"
  ;;
esac

