#!/bin/sh

RRDPATH=/root
PNGPATH=/var/www

# $1 - id
create()
{
  rrdtool create $RRDPATH/cisco2821-$1.rrd \
  DS:ifInOctets1:COUNTER:600:0:12500000 \
  DS:ifOutOctets1:COUNTER:600:0:12500000 \
  DS:ifInOctets2:COUNTER:600:0:12500000 \
  DS:ifOutOctets2:COUNTER:600:0:12500000 \
  DS:ifInOctets3:COUNTER:600:0:12500000 \
  DS:ifOutOctets3:COUNTER:600:0:12500000 \
  DS:ifInOctets4:COUNTER:600:0:12500000 \
  DS:ifOutOctets4:COUNTER:600:0:12500000 \
  DS:ifInOctets5:COUNTER:600:0:12500000 \
  DS:ifOutOctets5:COUNTER:600:0:12500000 \
  DS:ifInOctets6:COUNTER:600:0:12500000 \
  DS:ifOutOctets6:COUNTER:600:0:12500000 \
  RRA:AVERAGE:0.5:1:288 \
  RRA:AVERAGE:0.5:12:336 \
  RRA:AVERAGE:0.5:228:366 \
  RRA:AVERAGE:0.5:2016:261
}

# $1 - id
# $2 - host ip
# $3 - community
update()
{
  a=`snmpget -v1 -c $3 -Ov $2 \
  ifInOctets.1 ifOutOctets.1 \
  ifInOctets.2 ifOutOctets.2 \
  ifInOctets.3 ifOutOctets.3 \
  ifInOctets.4 ifOutOctets.4 \
  ifInOctets.5 ifOutOctets.5 \
  ifInOctets.6 ifOutOctets.6 \
  | awk '{printf ":"$2;}'`

  rrdtool update $RRDPATH/cisco2821-$1.rrd N$a
}

# $1 - id
# $2 - period
build()
{
  for i in 1 2 3 4 5 6
  do
    rrdtool graph $PNGPATH/cisco2821-$1-$i-$2.png --start=now-$2 --end=now \
    --width 480 --height 240 \
    --slope-mode --vertical-label 'входящих(-)/исходящих(+) бит/сек' \
    --title "cisco2821 $1 трафик на интерфейсе №$i, $2" \
    DEF:in=$RRDPATH/cisco2821-$1.rrd:ifInOctets$i:AVERAGE \
    'CDEF:in2=0,in,-,8,*' \
    'LINE2:in2#0000FFFF:Входящий, бит/сек' \
    VDEF:inavg=in2,AVERAGE \
    'LINE1:inavg#7777FFFF:Средний входящий, бит/сек' \
    DEF:out=$RRDPATH/cisco2821-$1.rrd:ifOutOctets$i:AVERAGE \
    'CDEF:out2=out,8,*' \
    'LINE2:out2#FF0000FF:Исходящий, бит/сек' \
    VDEF:outavg=out2,AVERAGE \
    'LINE1:outavg#FF7777FF:Средний исходящий, бит/сек' \
    LINE1:0#000000FF > /dev/null 2>&1
  done
}

# $1 - id
html()
{

cat - > $PNGPATH/cisco2821-$1.html <<END
<html>
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <title>Графики загрузки интерфейсов Cisco 2821 #$1</title>
  </head>
  <body>
    <div align="center">
    <h3>Графики загрузки интерфейсов Cisco 2821 #$1</h3>
      <table>
END

cat - > $PNGPATH/cisco2821-$1-arc.html <<END
<html>
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <title>Графики загрузки интерфейсов Cisco 2821 #$1</title>
  </head>
  <body>
    <div align="center">
    <h3>Графики загрузки интерфейсов Cisco 2821 #$1</h3>
      <table>
END

  for i in 1 2 3 4 5 6
  do
    cat - >> $PNGPATH/cisco2821-$1.html <<END
        <tr>
          <td id="$i"><img src="cisco2821-$1-$i-1day.png"></td>
          <td><img src="cisco2821-$1-$i-2weeks.png"></td>
          <td><a href="cisco2821-$1-arc.html#$i">&gt;&gt;</a></td>
        </tr>
END
  done

  for i in 1 2 3 4 5 6
  do
    cat - >> $PNGPATH/cisco2821-$1-arc.html <<END
        <tr>
          <td><a href="cisco2821-$1.html#$i">&lt;&lt;</a></td>
          <td id="$i"><img src="cisco2821-$1-$i-1year.png"></td>
          <td><img src="cisco2821-$1-$i-5years.png"></td>
        </tr>
END
  done

  cat - >> $PNGPATH/cisco2821-$1.html <<END
      </table>
    </div>
  </body>
</html>
END

  cat - >> $PNGPATH/cisco2821-$1-arc.html <<END
      </table>
    </div>
  </body>
</html>
END

}

case "$1" in
  create)
    create $2
  ;;
  update)
    update $2 $3 $4
  ;;
  build)
    build $2 $3
  ;;
  html)
    html $2
  ;;
  *)
    NAME=`basename $0`
    echo "$NAME - Tracking interfaces traffic on Cisco 2821"
    echo "Usage: $NAME create <id> - create database with <id>"
    echo "       $NAME update <id> <ip> <community> - fetch counters from router to database"
    echo "       $NAME build <id> <period> - build graph for <period>"
    echo "       $NAME html <id> - build html's"
  ;;
esac

