#!/bin/sh

RRDPATH=/root
PNGPATH=/var/www

# Kyocera Mita FS-1118MFP

# $1 - id
create()
{
  rrdtool create $RRDPATH/fs-1118mfp-$1.rrd \
  DS:ScanTotalPages:GAUGE:600:0:U \
  DS:PrintTotalPages:GAUGE:600:0:U \
  RRA:AVERAGE:0.5:1:288 \
  RRA:AVERAGE:0.5:12:336 \
  RRA:AVERAGE:0.5:228:366 \
  RRA:AVERAGE:0.5:2016:261
}

# $1 - id
# $2 - host ip
# $3 - community
update()
{
  a=`snmpget -v1 -c $3 -Ov $2 \
  enterprises.1347.46.10.1.1.5.3 \
  enterprises.1347.43.10.1.1.12.1.1 \
  | awk '{printf ":"$2;}'`

  rrdtool update $RRDPATH/fs-1118mfp-$1.rrd N$a
}

# $1 - id
# $2 - period
build()
{
  rrdtool graph $PNGPATH/fs-1118mfp-$1-$2.png --start=now-$2 --end=now \
  --width 480 --height 240 \
  --slope-mode --vertical-label 'Отсканировани, напечатано страниц' \
  --title "Kyocera Mita FS-1118MFP $1 отсканировано, напечатано страниц, $2" \
  DEF:stotal=$RRDPATH/fs-1118mfp-$1.rrd:ScanTotalPages:AVERAGE \
  CDEF:stotal2=0,stotal,- \
  'LINE2:stotal2#0000FFFF:Всего отсканировано страниц' \
  DEF:ptotal=$RRDPATH/fs-1118mfp-$1.rrd:PrintTotalPages:AVERAGE \
  'LINE2:ptotal#FF0000FF:Всего напечатано страниц' \
  LINE1:0#000000FF > /dev/null 2>&1
}

# $1 - id
html()
{

cat - > $PNGPATH/fs-1118mfp-$1.html <<END
<html>
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <title>Графики сканирования, копирования и печати Kyocera Mita FS-1118MFP #$1</title>
  </head>
  <body>
    <div align="center">
    <h3>Графики сканирования, копирования и печати Kyocera Mita FS-1118MFP #$1</h3>
      <table>
        <tr>
          <td><img src="fs-1118mfp-$1-1day.png"></td>
          <td><img src="fs-1118mfp-$1-2weeks.png"></td>
          <td><a href="fs-1118mfp-$1-arc.html">&gt;&gt;</a></td>
        </tr>
      </table>
    </div>
  </body>
</html>
END

cat - > $PNGPATH/fs-1118mfp-$1-arc.html <<END
<html>
  <head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <title>Графики сканирования, копирования и печати Kyocera Mita FS-1118MFP #$1</title>
  </head>
  <body>
    <div align="center">
    <h3>Графики сканирования, копирования и печати Kyocera Mita FS-1118MFP #$1</h3>
      <table>
        <tr>
          <td><a href="fs-1118mfp-$1.html">&lt;&lt;</a></td>
          <td><img src="fs-1118mfp-$1-1year.png"></td>
          <td><img src="fs-1118mfp-$1-5years.png"></td>
        </tr>
      </table>
    </div>
  </body>
</html>
END

}

case "$1" in
  create)
    create $2
  ;;
  update)
    update $2 $3 $4
  ;;
  build)
    build $2 $3
  ;;
  html)
    html $2
  ;;
  *)
    NAME=`basename $0`
    echo "$NAME - Tracking parameters from Kyocera Mita FS-1118MFP"
    echo "Usage: $NAME create <id> - create database with <id>"
    echo "       $NAME update <id> <ip> <community> - fetch counters from router to database"
    echo "       $NAME build <id> <period> - build graph for <period>"
    echo "       $NAME html <id> - build html's"
  ;;
esac

